@@ -486,7 +486,7 @@ public:
         std::cout << "Got " << c.size() << " W-mers at end of descent.\n";
         boost::timer t;
 #endif // STEME_LOG_TIMING_INFO
-        boost::sort( c, w_mer_evaluation< Spec >::comp_score() );
+        boost::sort( c, typename w_mer_evaluation< Spec >::comp_score() );
 #ifdef STEME_LOG_TIMING_INFO
         std::cout << "Sort took " << t.elapsed() << " seconds.\n";
         t.restart();
